[−][src]Struct async_socks5::SocksDatagram
A UDP socket that sends packets through a proxy.
Implementations
impl<S> SocksDatagram<S> where
S: AsyncWriteExt + AsyncReadExt + Send + Unpin, [src]
S: AsyncWriteExt + AsyncReadExt + Send + Unpin,
pub async fn associate<A>(
__arg0: S,
socket: UdpSocket,
auth: Option<Auth>,
association_addr: Option<A>
) -> Result<Self> where
A: Into<AddrKind>, [src]
__arg0: S,
socket: UdpSocket,
auth: Option<Auth>,
association_addr: Option<A>
) -> Result<Self> where
A: Into<AddrKind>,
Creates SocksDatagram. Performs UDP ASSOCIATE under the hood.
pub fn proxy_addr(&self) -> &AddrKind[src]
pub fn get_ref(&self) -> &UdpSocket[src]
pub fn get_mut(&mut self) -> &mut UdpSocket[src]
pub fn into_inner(self) -> (S, UdpSocket)[src]
pub async fn send_to<A, '_, '_>(
&'_ mut self,
buf: &'_ [u8],
addr: A
) -> Result<usize> where
A: Into<AddrKind>, [src]
&'_ mut self,
buf: &'_ [u8],
addr: A
) -> Result<usize> where
A: Into<AddrKind>,
pub async fn recv_from<'_, '_>(
&'_ mut self,
buf: &'_ mut [u8]
) -> Result<(usize, AddrKind)>[src]
&'_ mut self,
buf: &'_ mut [u8]
) -> Result<(usize, AddrKind)>
pub fn split(self) -> (SocksDatagramRecvHalf<S>, SocksDatagramSendHalf<S>)[src]
Splits SocksDatagram into two halves to send and receive data concurrently
pub fn reunite(
recv: SocksDatagramRecvHalf<S>,
send: SocksDatagramSendHalf<S>
) -> Result<Self, (SocksDatagramSendHalf<S>, SocksDatagramRecvHalf<S>)> where
S: Debug, [src]
recv: SocksDatagramRecvHalf<S>,
send: SocksDatagramSendHalf<S>
) -> Result<Self, (SocksDatagramSendHalf<S>, SocksDatagramRecvHalf<S>)> where
S: Debug,
Tries to recover SocksDatagram from two halves.
Succeeds if halves are from the same call to SocksDatagram::split.